Package 'fungaltraits'

Title: A dynamically-updating versioned trait database for fungi
Description: A functional trait database for fungi.
Authors: Will Cornwell [aut, cre], Habacuc Flores [aut]
Maintainer: Will Cornwell <[email protected]>
License: MIT + file LICENSE
Version: 0.0.3
Built: 2026-05-28 10:22:35 UTC
Source: https://github.com/traitecoevo/fungaltraits

Help Index


Fungal trait database

Description

This function provides access to the fungal traits database

Usage

fungal_traits(version = NULL, path = NULL)

fungal_traits_versions(local = TRUE, path = NULL)

fungal_traits_version_current(local = TRUE, path = NULL)

fungal_traits_del(version, path = NULL)

Arguments

version

Version number. The default will load the most recent version on your computer or the most recent version known to the package if you have never downloaded the data before. With plant_lookup_del, specifying version=NULL will delete all data sets.

path

Path to store the data at. If not given, datastorr will use rappdirs to find the best place to put persistent application data on your system. You can delete the persistent data at any time by running mydata_del(NULL) (or mydata_del(NULL, path) if you use a different path).

local

Logical indicating if local or github versions should be polled. With any luck, local=FALSE is a superset of local=TRUE. For mydata_version_current, if TRUE, but there are no local versions, then we do check for the most recent github version.

Details

The data within this lookup table comes from many original sources. For speedy access to the data within R use this function. For access to the full meta-data, download the zip file associated with the Github release.

Examples

#
# see the format of the resource
#
head(fungal_traits())
#
#