| Title: | A dynamically-updating versioned trait database for fungi |
|---|---|
| Description: | A functional trait database for fungi. |
| Authors: | Will Cornwell [aut, cre], Habacuc Flores [aut] |
| Maintainer: | Will Cornwell <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.3 |
| Built: | 2026-05-28 10:22:35 UTC |
| Source: | https://github.com/traitecoevo/fungaltraits |
This function provides access to the fungal traits database
fungal_traits(version = NULL, path = NULL) fungal_traits_versions(local = TRUE, path = NULL) fungal_traits_version_current(local = TRUE, path = NULL) fungal_traits_del(version, path = NULL)fungal_traits(version = NULL, path = NULL) fungal_traits_versions(local = TRUE, path = NULL) fungal_traits_version_current(local = TRUE, path = NULL) fungal_traits_del(version, path = NULL)
version |
Version number. The default will load the most
recent version on your computer or the most recent version known
to the package if you have never downloaded the data before.
With |
path |
Path to store the data at. If not given,
|
local |
Logical indicating if local or github versions should
be polled. With any luck, |
The data within this lookup table comes from many original sources. For speedy access to the data within R use this function. For access to the full meta-data, download the zip file associated with the Github release.
# # see the format of the resource # head(fungal_traits()) # ## # see the format of the resource # head(fungal_traits()) # #